#!/usr/bin/env python3
"""
DNS Resolver Script
Parameters:
    - hostname: Target hostname to resolve
Additional parameters in comments:
    - record_type: DNS record type (A, AAAA, MX, etc.)
"""
import socket
import argparse
import sys

def resolve_dns(hostname):
    try:
        # Get IPv4 address
        ipv4 = socket.gethostbyname(hostname)
        print(f"IPv4 Address: {ipv4}")
        
        # Get all address info
        all_info = socket.getaddrinfo(hostname, None)
        for info in all_info:
            addr = info[4][0]
            family = "IPv4" if info[0] == socket.AF_INET else "IPv6"
            print(f"{family} Address: {addr}")
            
    except socket.gaierror as e:
        print(f"DNS resolution failed: {e}")
        sys.exit(1)

if __name__ == "__main__":
    parser = argparse.ArgumentParser(description="DNS Resolver Tool")
    parser.add_argument("hostname", help="Hostname to resolve")
    args = parser.parse_args()
    
    resolve_dns(args.hostname)
